pandas-msgpack
==============

|Travis Build Status| |Appveyor Build Status| |Version Status| |Coverage Status|

**pandas-msgpack** is a package providing an interface to msgpack from pandas


Installation
------------


Install latest release version via conda
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: shell

   $ conda install pandas-msgpack --channel conda-forge

Install latest release version via pip
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: shell

   $ pip install pandas-msgpack

Install latest development version
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: shell

    $ pip install git+https://github.com/pydata/pandas-msgpack.git


Usage
-----

See the `pandas-msgpack documentation <https://pandas-msgpack.readthedocs.io/>`_ for more details.

.. |Travis Build Status| image:: https://travis-ci.org/pydata/pandas-msgpack.svg?branch=master
   :target: https://travis-ci.org/pydata/pandas-msgpack
.. |Appveyor Build Status| image:: https://ci.appveyor.com/api/projects/status/5716aqchorgwmwxf/branch/master?svg=true
   :target: https://ci.appveyor.com/project/jreback/pandas-msgpack
.. |Version Status| image:: https://img.shields.io/pypi/v/pandas-msgpack.svg
   :target: https://pypi.python.org/pypi/pandas-msgpack/
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/pydata/pandas-msgpack.svg
   :target: https://codecov.io/gh/pydata/pandas-msgpack/
